import PageContent from '@/components/PageContent';
import TabsContent from '@/components/TabsContent';
import { queryDeviceList } from '@/services/device';
import { useParams, useRequest } from '@umijs/max';
import { Button, Collapse, List, Space } from 'antd';
import { useMemo } from 'react';
const img = require('@/assets/deviceManager/device01.png');
const chartIcon = require('@/assets/deviceManager/chartIcon.png');
const DeviceManager = () => {
  const { projectId } = useParams();
  const { data, run, loading } = useRequest((data) => queryDeviceList(data), {
    defaultParams: [projectId],
  });

  const onChange = (tab) => {
    console.log(tab);
  };
  return (
    <PageContent style={{ backgroundColor: 'gray' }}>
      <TabsContent
        defaultActiveKey="1"
        onChange={onChange}
        items={[
          {
            label: `设备管理`,
            key: '1',
            children: <Device data={data} loading={loading} />,
          },
          {
            label: `备品管理`,
            key: '2',
            children: <SparePart />,
          },
        ]}
      />
    </PageContent>
  );
};
const Device = ({ data = [] }) => {
  //处理数据
  const dataSource = useMemo(() => {
    const total = data?.reduce((total, item) => item.Count, 0);
    const items = data?.map((item, idx) => {
      const itemLen = item?.List?.length;
      return {
        key: idx,
        label: (
          <div style={{ display: 'flex', justifyContent: 'space-between' }}>
            <span>{item.Type}</span>
            <span>{itemLen}个</span>
          </div>
        ),
        children: (
          <div style={{ position: 'relative' }}>
            <List
              header={null}
              footer={null}
              dataSource={item.List}
              renderItem={(cur) => (
                <List.Item style={{ justifyContent: 'left' }}>
                  <span style={{ width: '30%' }}> {cur.Code} </span>
                  <span> {cur.Name} </span>
                </List.Item>
              )}
            />
          </div>
        ),
      };
    });
    return { total, items };
  }, [data]);
  const onChange = (key) => {
    console.log(key);
  };
  return (
    <div style={{ width: '100%' }}>
      <div
        style={{
          display: 'flex',
          borderRadius: '10px',
          backgroundColor: 'white',
          justifyContent: 'space-around',
        }}
      >
        <img style={{ width: '30%' }} src={img} />
        <div>
          <div>{dataSource?.total}</div>
          <div>设备总数</div>
        </div>
        <div>
          <div
            style={{
              display: 'flex',
            }}
          >
            <div
              style={{
                width: '20px',
                height: '20px',
                backgroundColor: 'green',
                borderRadius: '10px',
              }}
            />
            <div>运行</div>
            <div>137</div>
          </div>
          <div
            style={{
              display: 'flex',
            }}
          >
            <div
              style={{
                width: '20px',
                height: '20px',
                backgroundColor: 'green',
                borderRadius: '10px',
              }}
            />
            <div>运行</div>
            <div>137</div>
          </div>
          <div
            style={{
              display: 'flex',
            }}
          >
            <div
              style={{
                width: '20px',
                height: '20px',
                backgroundColor: 'green',
                borderRadius: '10px',
              }}
            />
            <div>运行</div>
            <div>137</div>
          </div>
        </div>
      </div>
      <Space>
        <Button shape="round">全部</Button>
        <Button shape="round">维修</Button>
        <Button shape="round">保养</Button>
      </Space>
      <Collapse
        defaultActiveKey={['1']}
        bordered={false}
        // expandIcon={() => <div> 个</div>}
        onChange={onChange}
        items={dataSource?.items}
      />
    </div>
  );
};
const SparePart = () => {
  return (
    <div>
      <div
        style={{
          display: 'flex',
          borderRadius: '10px',
          backgroundColor: 'white',
          justifyContent: 'space-around',
        }}
      >
        <img style={{ width: '30%' }} src={img} />
        <div>
          <div>410</div>
          <div>在库数量（个）</div>
        </div>
        <img style={{ position: 'absolute', right: '20px' }} src={chartIcon} />
      </div>
    </div>
  );
};

export default DeviceManager;
